@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE DataKinds, GADTs, PolyKinds, RankNTypes, TypeOperators,
              TypeFamilies, StarIsType, TypeApplications #-}
 
@@ -9,6 +8,7 @@ import Data.Kind (Type)
 
 data Peano = Zero | Succ Peano
 
+type Length :: [k] -> Peano
 type family Length (as :: [k]) :: Peano where
   Length (a : as) = Succ (Length as)
   Length '[]      = Zero
@@ -21,6 +21,7 @@ newtype instance Nat (a :: k -> Type) :: (k -> Type) -> Type where
 
 data T f (a :: k) = MkT (f a)
 
+type F1 :: k -> (k -> Type) -> Type
 type family F1 (a :: k) (f :: k -> Type) :: Type where
   F1 @Peano a f = T @Peano f a
 
