@@ -5,4 +5,4 @@ module Example where
 import Data.Typeable
 import GHC.Exts
 
-data Wat (a :: TYPE (SumRep '[LiftedRep, IntRep])) = Wat a
+data Wat (a :: TYPE (SumRep '[BoxedRep Lifted, IntRep])) = Wat a
